#![cfg(feature = "std")]
use std::{
    io::{BufReader, Read, Seek},
    mem::size_of,
};

use test_log::test;

use btrfs::{structs::*, tree::Tree, Btrfs};

#[test]
fn superblock() {
    let mut file = std::fs::File::open("btrfs.img").expect("btrfs image");

    let reader = BufReader::new(file);
    let volume = Btrfs::new(reader).expect("volume");
    let sb = volume.superblock();

    println!("{sb:#?}");

    assert!(sb.verify_magic());
    assert!(sb.verify_checksum());
}

#[test]
fn iter_sys_chunks() {
    let mut file = std::fs::File::open("btrfs.img").expect("btrfs image");

    let reader = BufReader::new(file);
    let volume = Btrfs::new(reader).expect("volume");
    let sb = volume.superblock();

    let result = Btrfs::<BufReader<std::fs::File>>::bootstrap_chunk_tree(&sb);

    println!("{result:#?}");
}

#[test]
fn iter_root() {
    let mut file = std::fs::File::open("btrfs.img").expect("btrfs image");

    let reader = BufReader::new(file);
    let mut volume = Btrfs::new(reader).expect("volume");
    let sb = volume.superblock();

    println!("{:#?}", volume);

    volume.find_default_subvol();
}
